@@ -1,6 +1,6 @@
 from grokcore.view import path
 from grokcore.component import name
-from hurry.resource import ResourceInclusion, GroupInclusion
+from hurry.resource import ResourceInclusion, GroupInclusion, mode
 
 from megrok.resource.directives import include, use_hash, resource
 from megrok.resource.components import Library, ResourceLibrary
