@@ -5,7 +5,7 @@ from hurry.resource import ResourceInclusion
 from hurry.resource.interfaces import IInclusion
 from megrok.resource.interfaces import IResourcesIncluder
 from zope.interface import classImplements
-from zope.interface.declarations import addClassAdvisor, _implements_advice
+from zope.interface.declarations import addClassAdvisor
 
 
 def validateInclusion(directive, value):
